Author: Marina Guvakova

# Welcome to `g3mclass`!

`g3mclass` is Gaussian mixture modeling software for the molecular assay data classification.

Usage:

1. Open a sample data file: File>Open example

2. Data from columns gene W (test) and gene W (ref) in tab ‘Data’ are used to learn Gaussian mixtures, one mixture per each molecular assay analyte (gene W in this case).

3. If needed, the model setting parameters can be tuned in tab ‘Parameters’. When done, click on Action>Learn model

4. The subsequent model parameters can be examined in tab ‘Model’ and model plots can be viewed in tab ‘Model plots’.

5. Data from columns gene W (test), gene W (ref), and gene W (query) are automatically classified using three consecutive classifications: ‘proba’> ‘cutoff’ >’s. cutoff’

6. Three classification results can be examined in tabs ‘Test class’, ’Ref class’, and ‘Query class’.

7. The individual sample classification with ID can be viewed in tab ‘Heatmaps’.

8. The outputs including parameters settings (models and graphics), model (parameters and plots), and classification results (spreadsheets and heatmaps), plus the original input data can be archived in a zipped folder: File>Save

For legal information, see Help>About